@@ -1,7 +1,7 @@
-/* Produced by texiweb from libavl.w on 2002/08/24 at 13:21. */
+/* Produced by texiweb from libavl.w. */
 
 /* libavl - library for manipulation of binary trees.
-   Copyright (C) 1998-2002 Free Software Foundation, Inc.
+   Copyright (C) 1998-2002, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -572,6 +572,9 @@ bst_t_replace (struct bst_traverser *trav, void *new)
   return old;
 }
 
+/* Destroys |new| with |bst_destroy (new, destroy)|,
+   first setting right links of nodes in |stack| within |new|
+   to null pointers to avoid touching uninitialized data. */
 static void
 copy_error_recovery (struct bst_node **stack, int height,
                      struct bst_table *new, bst_item_func *destroy)
