@@ -1,7 +1,7 @@
-/* Produced by texiweb from libavl.w on 2002/08/24 at 13:21. */
+/* Produced by texiweb from libavl.w. */
 
 /* libavl - library for manipulation of binary trees.
-   Copyright (C) 1998-2002 Free Software Foundation, Inc.
+   Copyright (C) 1998-2002, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -656,6 +656,9 @@ pavl_t_replace (struct pavl_traverser *trav, void *new)
   return old;
 }
 
+/* Destroys |new| with |pavl_destroy (new, destroy)|,
+   first initializing right links in |new| that have
+   not yet been initialized at time of call. */
 static void
 copy_error_recovery (struct pavl_node *q,
                      struct pavl_table *new, pavl_item_func *destroy)
