@@ -1,7 +1,7 @@
-/* Produced by texiweb from libavl.w on 2002/08/24 at 13:21. */
+/* Produced by texiweb from libavl.w. */
 
 /* libavl - library for manipulation of binary trees.
-   Copyright (C) 1998-2002 Free Software Foundation, Inc.
+   Copyright (C) 1998-2002, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -333,10 +333,14 @@ tavl_delete (struct tavl_table *tree, const void *item)
   if (tree->tavl_root == NULL)
     return NULL;
 
-  p = (struct tavl_node *) &tree->tavl_root;
-  for (cmp = -1; cmp != 0;
-       cmp = tree->tavl_compare (item, p->tavl_data, tree->tavl_param))
+  q = (struct tavl_node *) &tree->tavl_root;
+  p = tree->tavl_root;
+  dir = 0;
+  for (;;)
     {
+      cmp = tree->tavl_compare (item, p->tavl_data, tree->tavl_param);
+      if (cmp == 0)
+        break;
       dir = cmp > 0;
 
       q = p;
@@ -812,6 +816,9 @@ copy_node (struct tavl_table *tree,
   return 1;
 }
 
+/* Destroys |new| with |tavl_destroy (new, destroy)|,
+   first initializing the right link in |new| that has
+   not yet been initialized. */
 static void
 copy_error_recovery (struct tavl_node *p,
                      struct tavl_table *new, tavl_item_func *destroy)
