@@ -1,7 +1,7 @@
-/* Produced by texiweb from libavl.w on 2002/08/24 at 13:21. */
+/* Produced by texiweb from libavl.w. */
 
 /* libavl - library for manipulation of binary trees.
-   Copyright (C) 1998-2002 Free Software Foundation, Inc.
+   Copyright (C) 1998-2002, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -508,6 +508,9 @@ copy_node (struct tbst_table *tree,
   return 1;
 }
 
+/* Destroys |new| with |tbst_destroy (new, destroy)|,
+   first initializing the right link in |new| that has
+   not yet been initialized. */
 static void
 copy_error_recovery (struct tbst_node *p,
                      struct tbst_table *new, tbst_item_func *destroy)
