@@ -1,7 +1,7 @@
-/* Produced by texiweb from libavl.w on 2002/08/24 at 13:21. */
+/* Produced by texiweb from libavl.w. */
 
 /* libavl - library for manipulation of binary trees.
-   Copyright (C) 1998-2002 Free Software Foundation, Inc.
+   Copyright (C) 1998-2002, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -829,8 +829,9 @@ parse_command_line (char **args, struct test_options *options)
           break;
 
         case 'V':
-          fputs ("GNU libavl 2.0.1\n"
-                 "Copyright (C) 1998-2002 Free Software Foundation, Inc.\n"
+          fputs ("GNU libavl 2.0.2\n"
+                 "Copyright (C) 1998-2002, 2004 "
+                 "Free Software Foundation, Inc.\n"
                  "This program comes with NO WARRANTY, not even for\n"
                  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
                  "You may redistribute copies under the terms of the\n"
@@ -1007,7 +1008,7 @@ main (int argc, char *argv[])
   parse_command_line (argv, &opts);
 
   if (opts.verbosity >= 0)
-    fputs ("bst-test for GNU libavl 2.0.1; use --help to get help.\n", stdout);
+    fputs ("bst-test for GNU libavl 2.0.2; use --help to get help.\n", stdout);
 
   if (!opts.seed_given)
     opts.seed = time_seed () % 32768u;
