@@ -1,5 +1,5 @@
 /* texitree - draws PostScript and plain text tree diagrams
-   Copyright (C) 2000 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -392,7 +392,7 @@ main (int argc, char *argv[])
       fprintf
 	(stderr,
 	 "texitree 0.9.0\n"
-	 "Copyright (C) 2000 Free Software Foundation, Inc.\n"
+	 "Copyright (C) 2002, 2004 Free Software Foundation, Inc.\n"
 	 "texiweb comes with NO WARRANTY, to the extent permitted by law,\n"
 	 "not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 	 "You may redistribute copies of texiweb under the terms of the GNU\n"
@@ -486,35 +486,35 @@ main (int argc, char *argv[])
       space_create (&page, page_width, page_height);
 
       printf ("%%!PS-Adobe-3.0 EPSF-3.0\n"
-	      "%%%%BoundingBox: %.0f %.0f %.0f %.0f\n"
-	      "/ED { exch def } def\n"
-	      "/MT { moveto } def\n"
-	      "/LT { lineto } def\n"
-	      "/L { newpath MT LT stroke } bind def\n"
-	      "/F { exch findfont exch scalefont setfont } bind def\n"
-	      "/C { dup 3 index add 2 index MT 0 360 arc stroke } "
-	      "bind def\n"
-	      "/SG { 100 div setgray } bind def\n"
-	      "/D { SG dup 3 index add 2 index MT 0 360 arc fill 0 SG } "
-	      "bind def\n"
-	      "/TC { SG dup stringwidth pop 2 div 4 -1 roll exch sub\n"
-	      "     3 -1 roll MT show 0 SG } bind def\n"
-	      "/TR { SG dup stringwidth pop 4 -1 roll exch sub\n"
-	      "     3 -1 roll MT show 0 SG } bind def\n"
-	      "/TL { SG 0 4 -1 roll exch sub\n"
-	      "     3 -1 roll MT show 0 SG } bind def\n"
-	      "/S { gsave /Symbol 12 F 0 TC grestore } bind def\n"
-	      "/T { [2 1] 0 setdash MT curveto stroke } bind def\n"
-	      "/A { [] 0 setdash /y ED /x ED x 1.4 sub y 4 sub\n"
-	      "     MT x y LT x 1.4 add y 4 sub LT fill } def\n"
-	      "/Q { /y1 ED /x1 ED /y0 ED /x0 ED\n"
-	      "     x0 y0 MT x1 y0 LT x1 y1 LT x0 y1 LT\n"
-	      "     x0 y0 LT closepath } def\n"
-	      "/SD { Q stroke } def\n"
-	      "/SS { SG Q fill 0 SG } def\n"
-	      "/Helvetica 12 F\n",
-	      space_xc (&page, x0), space_yc (&page, y1),
+	      "%%%%BoundingBox: %.0f %.0f %.0f %.0f\n",
+              space_xc (&page, x0), space_yc (&page, y1),
 	      space_xc (&page, x1), space_yc (&page, y0));
+      fputs ("/ED { exch def } def\n"
+             "/MT { moveto } def\n"
+             "/LT { lineto } def\n"
+             "/L { newpath MT LT stroke } bind def\n"
+             "/F { exch findfont exch scalefont setfont } bind def\n"
+             "/C { dup 3 index add 2 index MT 0 360 arc stroke } "
+             "bind def\n"
+             "/SG { 100 div setgray } bind def\n"
+             "/D { SG dup 3 index add 2 index MT 0 360 arc fill 0 SG } "
+             "bind def\n"
+             "/TC { SG dup stringwidth pop 2 div 4 -1 roll exch sub\n"
+             "     3 -1 roll MT show 0 SG } bind def\n"
+             "/TR { SG dup stringwidth pop 4 -1 roll exch sub\n", stdout);
+      fputs ("     3 -1 roll MT show 0 SG } bind def\n"
+             "/TL { SG 0 4 -1 roll exch sub\n"
+             "     3 -1 roll MT show 0 SG } bind def\n"
+             "/S { gsave /Symbol 12 F 0 TC grestore } bind def\n"
+             "/T { [2 1] 0 setdash MT curveto stroke } bind def\n"
+             "/A { [] 0 setdash /y ED /x ED x 1.4 sub y 4 sub\n"
+             "     MT x y LT x 1.4 add y 4 sub LT fill } def\n"
+             "/Q { /y1 ED /x1 ED /y0 ED /x0 ED\n"
+             "     x0 y0 MT x1 y0 LT x1 y1 LT x0 y1 LT\n"
+             "     x0 y0 LT closepath } def\n"
+             "/SD { Q stroke } def\n"
+             "/SS { SG Q fill 0 SG } def\n"
+             "/Helvetica 12 F\n", stdout);
 
       y += PS_TOP_MARGIN;
     }
